@@ -40,8 +40,8 @@ class ProductRequest(BaseModel):
     product_key: str 
     price: float
     tax_included: Optional[bool]
-    taxability: Optional[str]
-    taxes: Optional[List[Taxes]]
+    taxability: Optional[str] = "01"
+    taxes: Optional[List[Taxes]] = None
     local_taxes: Optional[List[LocalTaxes]]
     unit_key: Optional[str]
     unit_name: Optional[str]
@@ -70,8 +70,8 @@ class ProductUpdateRequest(BaseModel):
     product_key: Optional[str]
     price: Optional[float]
     tax_included: Optional[bool]
-    taxability: Optional[str]
-    taxes: Optional[List[Taxes]]
+    taxability: Optional[str] = "01"
+    taxes: Optional[List[Taxes]] = None
     local_taxes: Optional[List[LocalTaxes]]
     unit_key: Optional[str]
     unit_name: Optional[str]
